@@ -564,6 +564,7 @@ $vals{1}{111}{translate_vertices} =
 [ "a", "i", "0\ny", "j",  "b", "f", "k", "l", "e",  "d", "0\nr", "0\na", "0\nq", "c", "g", "0\nt", "0\ns", "h" ],  
 [ [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0], [0, 2, 0],  [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0], [0, -2, 0] ], 
 [ "/zones/zone.geo" ], # source file
+[ "y" ] # long menus?
 ],
 ];
 # [ @vertexes_to_transl, Consider that after "p" you have to write "0\nq" ]
@@ -649,6 +650,7 @@ $vals{1}{111}{warp} =
 [ "a" , "d" , "e", "h" , "b" , "c", "f", "g" , "d" , "a" , "h", "e" , "c" , "b", "g", "f" ], # pairs of vertices defining axes
 [ "g", "i" ], # windows to be realigned
 "/zones/zone.geo", # zone geometry file
+"y" # long menus occurring in ESP-r? "y" or "n".
 ], 
 ];
 
@@ -675,6 +677,7 @@ $vals{1}{111}{reshape_windows} = [
 [ ( 40/100 ) ], # windows percentage base value
 [ ( 30/100 )], # windows percentage swing
 [ "k", "l", "m", "n" ], # vertex number of the windows to change
+[ "y" ] # there are long menus for items in ESP-r here? "y" or "n".
 ]
 ],
 ]; 
@@ -689,6 +692,7 @@ $vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE
 [216], # base values
 [ "/opts/default_configfile_control_constraints.pl" ], # swing values: still unused
 [ "e", "f", "g", "h", "0\nb\nb" , "0\nb\nd", "0\nb0\nb\nf", "0\nb\n0\nb\nh", "0\nb\n0\nb\nj" ], # letters of vertices in the esp-r geometry file. Here the letters have to be specified corresponding to the vertices whose position has to be changes through propagation of constraints.
+"y" # do you have long menus for items in ESP-r here? "y" or "n".
 ],
 ]; 
 
@@ -696,14 +700,13 @@ $vals{1}{111}{apply_constraints} = ##### APPLY PROPAGATION OF CONSTRAINTS TO THE
 $vals{1}{111}{constrain_geometry} = # This is similar to "apply_constraints", but more general, because the propagation here criteria has to be specified in the configuration file. 
 [  
 [
-[
 "/zones/zone.geo", # source file
 "/zones/zone.geo", # target file
 "/opts/default_configfile_geometry_constraints.pl", # configuration file for constraints. Here the criteria for propagation of constraints have to be specified.
 [ "k", "l", "m", "n" ], # vertex letters to be changed.
+"y", # long vertex letters (long menus) in ESP-r here? "y" or "n"
 [ 1, 1, 2, 1 ], # swings, corresponding point to point to vertexletters
 ], # THIS IS THE FIRST OPERATION IN SERIES. OTHER CAN BE ADDED.
-]
 ]; #
 ## THIS VARIABLE REGARDS GEOMETRY USER-IMPOSED CONSTRAINTS
 ## THIS CONSTRAINT CONFIGURATION FILE MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES:
@@ -723,14 +726,12 @@ $vals{1}{111}{constrain_geometry} = # This is similar to "apply_constraints", bu
 $vals{1}{111}{constrain_obstructions} = # To apply constraints to and from obstructions.
 [ 
 [
-[
 "a", # zone letter
 "/zones/zone.geo", # source file
 "/zones/zone.geo", # target file
 "/opts/default_configfile_obstruction_constraints.pl", # configuration file for constraints. Here the criteria for propagation of constraints have to be specified.
 [  "e", "f", "g", "h" ], # obstruction letters to be changed.
 "y" # act on construction too? "y" or "n". Note that constructions letters (as they appear in the construction database) and not construction names have to be given in the configuration files.
-],
 ], 
 ];
 ## THIS PART REGARDS USER-IMPOSED CONSTRAINTS ABOUT OBSTRUCTIONS
@@ -756,7 +757,6 @@ $vals{1}{111}{constrain_obstructions} = # To apply constraints to and from obstr
 
 
 $vals{1}{111}{vary_controls} = 
-[
 [ 
 [
 "/ctl/cell.ctl", # source file
@@ -793,19 +793,16 @@ $vals{1}{111}{vary_controls} =
 [ "f", "a", 0, 1, 0, 0 ], # SECOND LOOP AND FIRST CONTROL FOR THE SECOND LOOP FOR NETS; THEN BEGINNING HOUR SWING, SETPOINT SWING, ON-OFF (-1 OR 1), FRACTION
 ] # END OF NET CONTROLS
 ], # END OF DATA FOR THE FIRST SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE, ETC. NEW SEQUENCES CAN BE ADDED.
-]
 ];
 
 
 $vals{1}{111}{constrain_controls} = # to apply contraints to and from controls.
 [
 [
-[
 "/ctl/cell.ctl", # source file
 "/ctl/cell.ctl", # target file
 "/opts/default_configfile_control_constraints.pl", # config file 
 ],
-],
 ];
 ## THIS VARIABLE REGARDS CONTROL USER-IMPOSED CONSTRAINTS
 ## THIS CONSTRAINT CONFIGURATION FILE FILE MAKES AVAILABLE TO THE USER THE FOLLOWING VARIABLES:
@@ -836,7 +833,6 @@ $vals{1}{111}{constrain_controls} = # to apply contraints to and from controls.
 ## WITH THE FOLLOWING VARIABLES: @letters AND @period_letters
 
 $vals{1}{111}{vary_net} = 
-[
 [ 
 [
 "/nets/cell.afn", # source file
@@ -885,7 +881,6 @@ $vals{1}{111}{vary_net} =
 ], # END OF THE THIRD COMPONENT
 ] # END OF NET COMPONENTS
 ], # END OF DATA FOR THE FIRST SEQUENCE OF OPERATIONS IN THIS MORPHING PHASE, ETC. NEW SEQUENCES CAN BE ADDED.
-],
 ]; # If the alphabetical order is not accepted as an order to propagate constraints, a new order can be specificed
 ## WITH THE FOLLOWING VARIABLES:
 ## @node_letters AND @component_letters 
@@ -893,7 +888,6 @@ $vals{1}{111}{vary_net} =
 $vals{1}{111}{constrain_net} = 
 [
 [
-[
 "/nets/cell.afn", # source file
 "/nets/cell.afn", # target file
 "/opts/default_configfile_net_constraints.pl", # config file 
@@ -903,7 +897,6 @@ $vals{1}{111}{constrain_net} =
 # ALSO THE INTERNAL NODE WILL NEED A VALUE TO BE SPECIFIED, THAT IT WON'T BE USED.  THE EXCEEDING ITEMS WILL NOT BE USED. 
 # ALSO, THESE VALUES WILL NOT BE USED IF DIFFERENT ONES WILL BE CALCULATED THROUGH PROPAGATION OF CONSTRAINTS, DEPENDING ON THE INSTRUCTIONS IN THE CONFIG FILE
 ], 
-],
 ]; 
 ## THIS FILE CAN CONTAIN USER-IMPOSED CONSTRAINTS FOR MASS-FLOW NETWORKS TO BE READ BY OPT.
 ## IT MAKES AVAILABLE VARIABLES REGARDING THE SETTING OF NODES IN A NETWORK.
@@ -943,9 +936,7 @@ $vals{1}{111}{constrain_net} =
 ## @node_letters AND @component_letters (FOR NETS), @letters AND @period_letters (FOR CONTROLS)
 
 
-$vals{1}{111}{propagate_constraints} = 
-[
-[ 
+$vals{1}{111}{propagate_constraints} = [ 
 [
 [ "read_geo", # what to do
 "/zones/zone.geo", # source file
@@ -1008,7 +999,6 @@ $vals{1}{111}{propagate_constraints} =
 "n" # act on materials too? "y" or "n". That materials letters (as they appear in the material database) and not materials names have to be given in the configuration files.
 ]
 ],
-],
 ]; # THIS FILE CAN CONTAIN USER-IMPOSED CONSTRAINTS FOR MASS-FLOW NETWORKS TO BE READ BY OPT.
 ## IT MAKES AVAILABLE VARIABLES REGARDING THE SETTING OF NODES IN A NETWORK.
 ## THIS FILE ALLOWS TO MANIPULATE COMPOUND USER-IMPOSED CONSTRAINTS.
