@@ -17,6 +17,7 @@ use List::AllUtils qw(sum);
 use Statistics::Basic qw(:all);
 use Storable qw(dclone);
 use IO::Tee;
+use File::Copy qw( move copy );
 use Set::Intersection;
 use List::Compare;
 use Data::Dumper;
@@ -62,8 +63,8 @@ $simnetwork @themereports %simtitles %reporttitles %retrievedata
 $target %dowhat
 );
 
-$VERSION = '0.47.14'; # our $VERSION = '';
-$ABSTRACT = 'Sim::OPT it a tool for detailed metadesign. It manages parametric explorations through the ESP-r building performance simulation platform and performs optimization by block coordinate descent.';
+$VERSION = '0.48.1'; # our $VERSION = '';
+$ABSTRACT = 'Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. It adopts the block coordinate descent optimization method.';
 
 #################################################################################
 # Sim::OPT 
@@ -1017,7 +1018,7 @@ sub exe
 sub start
 {
 ###########################################
-print "THIS IS Sim::OPT (version 0.47.14),
+print "THIS IS Sim::OPT (version 0.47.16),
 a morphing and optimizazion program.
 
 .  .  .  .  .  .  .  .  .  .  .  .  .
@@ -1038,8 +1039,10 @@ sub opt
 
 	
 	&start;
+	# eval `cat $configfile`; # The file where the program data are
 
 	require $configfile;
+	#if ( not ( $outfile ) ) { $outfile = "$mypath/$file-$fileconfig-feedback.txt"; } 
 	if ( not ( $tofile ) ) { 
 		unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
 		{
@@ -1056,7 +1059,7 @@ sub opt
 #	if ($casefile) { eval `cat $casefile` or die( "$!" ); }
 #	if ($chancefile) { eval `cat $chancefile` or die( "$!" ); }
 
-	print "\nNow in Sim::OPT.\n";
+	print "\nNow in Sim::OPT. \n";
 		
 	#open( OUTFILE, ">>$outfile" ) or die "Can't open $outfile: $!"; 
 	open( TOFILE, ">>$tofile" ) or die "Can't open $tofile: $!"; 
@@ -1161,9 +1164,8 @@ Sim::OPT.
 
 =head1 DESCRIPTION
 
-Sim::OPT is an optimization and morphing program that can be used with any kind of simulation program that can receive text files as input and emit text files as output. Some of its optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by overlapping block coordinate descent (inexact Gauss-Seidel method). The Another optimization module (Sim::OPT::Takechange) seeks for the least explored search paths when exploring new search spaces. A morphing module (Sim::OPT::Morph) manipulates text files by targeting specific variables position and applying to them generic interpolation rules. The Sim::OPT::Parcoord3d module is dedicated to reporting and creating parallel coordinates plots in 3D.
-
-At a more specific level, Sim::OPT is aimed to assist the detailed metadesign of buildings by managing the ESP-r building performance simulation platform. For that specific target, it offers several additional morphing functions besides the generic one. Because of that, a working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is presently necessary to use most functionalitues of OPT. (Note that ESP-r must be compiled for text, not graphics, and for Linux).
+Sim::OPT is an optimization and morphing program that can be used with simulation programs receiving text files as input and emitting text files as output. Some of its optimization modules (Sim::OPT, Sim::OPT::Descent) pursue optimization by overlapping block coordinate descent (inexact Gauss-Seidel method). Another optimization module (Sim::OPT::Takechange) seeks for the least explored search paths when exploring new search spaces. Its morphing module (Sim::OPT::Morph) manipulates text files recognizing variables by position and applying to them generic interpolation rules. The Sim::OPT::Parcoord3d module converts 2D parallel coordinates plots to 3D.
+The morhing and reporting modules of Sim::OPT contain several functions specifically targeting the ESP-r building performance simulation platform. For that specific target, Sim::OPT offers several additional morphing functions besides the generic one. A working knowledge of ESP-r (http://www.esru.strath.ac.uk/Programs/ESP-r.htm) is necessary to use those functionalitues of OPT.
 
 To install Sim::OPT, the command <cpanm Sim::OPT> has to be issued as a superuser. OPT can then be loaded through the command <use Sim::OPT> in a Perl repl. To ease the launch, the batch file "opt" (which can be found packed in the "optw.tar.gz" file in "examples" folder in this distribution) may be copied in a work directory and the command <opt> may be issued (not as a superuser). That command will call the OPT's functions, following the settings specified in the configuration file, which has to be prepared in advance. When launched, OPT will ask the path to that file, which must contain a suitable description of the operations to be accomplished and point to an existing simulation model.
 
