@@ -16,6 +16,7 @@ use Statistics::Basic qw(:all);
 use Set::Intersection;
 use List::Compare;
 use IO::Tee;
+use File::Copy qw( move copy );
 use Data::Dumper;
 #$Data::Dumper::Indent = 0;
 #$Data::Dumper::Useqq  = 1;
@@ -199,7 +200,17 @@ sub sim    # This function launch the simulations in ESP-r
 				my $tooltype = $dowhat{simtools}{$counttool}; say TOFILE "\$tooltype " . dump( $tooltype );
 				
 				if ( $tooltype eq "esp-r" )
-				{					
+				{	
+					my $launchline;
+					unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
+					{
+						$launchline = "-file $simelt/cfg/$fileconfig -mode script";
+					}
+					else
+					{
+						$launchline = "-file $simelt\\cfg\\$fileconfig -mode script";
+					}
+					
 					say TOFILE "dump(\%simtitles): " . dump( %simtitles ); 
 					say TOFILE "dump(\$simtitles{\$counttool}): " . dump( $simtitles{$counttool} ); 
 					say TOFILE "dump(\@{ \$simtitles{\$counttool}): " . dump( @{ $simtitles{$counttool} } ); 	
@@ -265,7 +276,7 @@ sub sim    # This function launch the simulations in ESP-r
 								{
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile and $flfile." ;
 									my $printthis =	
-"bps -file $simelt$fileconfig -mode script<<XXX
+"bps $launchline<<XXX
 
 c
 $resfile
@@ -302,7 +313,7 @@ XXX
 								{
 									say "#Simulating case " . ($countcase + 1) . ", block " . ($countblock + 1) . ", parameter $countvar at iteration $countstep for tool $tooltype. Instance $countinstance: writing $resfile. " ;
 									my $printthis =
-"bps -file $simelt$fileconfig -mode script<<XXX
+"bps $launchline<<XXX
 
 c
 $resfile
@@ -364,7 +375,7 @@ $printthis
 						my $epresroot = $tempname . $epnewfragment ; say TOFILE "dump(\$epnewfile ): " . dump( $epnewfile ); 
 						
 						my $epnewpath;
-						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
+						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 						{ 
 							$epnewpath = $to . $epdir . "/" . $epnewfile; say TOFILE "dump(\$epnewpath ): " . dump( $epnewpath ); 
 						}
@@ -377,7 +388,7 @@ $printthis
 						my @changes = @simdos[ 12..$#simdos ]; say TOFILE "dump(\@changes ): " . dump( @changes ); 
 						if ( $tooltype eq "energyplus" ) # RESTORES DEFAULTS FOR ENERGYPLUS
 						{
-							unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
+							unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 							{
 								$outputdir = "/Output";
 							}
@@ -418,7 +429,7 @@ $printthis
 						my $simelt = $mypath . "$outputdir"; #say TOFILE "dump(\$simelt ): " . dump( $simelt ); 
 						
 						my $resfile;
-						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
+						unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 						{
 							$resfile = "$simelt/$epresroot$resfiletype"; #say TOFILE "dump(\$resfile ): " . dump( $resfile ); 
 						}
@@ -490,7 +501,7 @@ $printthis
 										{
 										
 										my $tempf = $epnewpath; #say TOFILE "dump(\$tempf1 ): " . dump( $tempf );
-										unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
+										unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 										{
 											$tempf =~ s/$to$epdir\///;  #say TOFILE "dump(\$tempf2 ): " . dump( $tempf ); 
 											$templaunch = $mypath . "/" . $tempf; #say TOFILE "dump(\$templaunch ): " . dump( $templaunch ); 
@@ -505,7 +516,7 @@ $printthis
 										`runenergyplus $templaunch $epwfile`;
 										#`rm -f $templaunch`;
 									}
-									unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) )
+									unless ( ( "$^O" eq "MSWin32" ) or ( "$^O" eq "MSWin64" ) ) 
 									{
 										print TOFILE "cp -f $epnewpath $templaunch\n";
 									}
